# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.125
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from helix_platform_api_public_client.models.message_category import MessageCategory  # noqa: E501

class TestMessageCategory(unittest.TestCase):
    """MessageCategory unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMessageCategory(self):
        """Test MessageCategory"""
        # inst = MessageCategory()

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.125
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import date, datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictStr, constr, validator
from helix_platform_api_public_client.models.intra_day_product_type import IntraDayProductType
from helix_platform_api_public_client.models.nomination_gate_status import NominationGateStatus

class IntraDayNominationGate(BaseModel):
    """
    IntraDayNominationGate
    """
    id: constr(strict=True) = Field(..., description="Virtual ID of a \"Workflow\" in the following format `{recurringWorkflowId}:{executionDay}`  Example: `684df173-4110-4e0d-b364-d2364388afe3:2024-06-01` ")
    product_type: IntraDayProductType = Field(..., alias="productType")
    name: StrictStr = Field(...)
    delivery_day: date = Field(..., alias="deliveryDay", description="One single calendar day, interpreted in **System Time**  - ISO 8601 compliant string in `yyyy-mm-dd` format ")
    mtu: datetime = Field(..., description="The first moment (inclusive) of an MTU period  - theoretically can be sent and received with any zone offset (until it marks the desired **absolute MTU start point** on the timeline) - in practice it is advised to transfer it in UTC timezone (with Z offset, \"Zulu time\") - ISO 8601 compliant string in `yyyy-mm-ddThh:mm:ss.SSSZ` format - only with `XX:00:00`, `XX:15:00`, `XX:30:00` and `XX:45:00` time parts are valid values (depending on MTU size) ")
    status: NominationGateStatus = Field(...)
    next_action_at: Optional[datetime] = Field(None, alias="nextActionAt", description="Date and time with zone information, marks an **absolute point** on the timeline  - theoretically can be sent and received with any zone offset (until it marks the desired **absolute point** on the timeline) - in practice it is advised to transfer it in UTC timezone (with Z offset, \"Zulu time\") - ISO 8601 compliant string in `yyyy-mm-ddThh:mm:ss.SSSZ` format ")
    __properties = ["id", "productType", "name", "deliveryDay", "mtu", "status", "nextActionAt"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> IntraDayNominationGate:
        """Create an instance of IntraDayNominationGate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> IntraDayNominationGate:
        """Create an instance of IntraDayNominationGate from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return IntraDayNominationGate.parse_obj(obj)

        _obj = IntraDayNominationGate.parse_obj({
            "id": obj.get("id"),
            "product_type": obj.get("productType"),
            "name": obj.get("name"),
            "delivery_day": obj.get("deliveryDay"),
            "mtu": obj.get("mtu"),
            "status": obj.get("status"),
            "next_action_at": obj.get("nextActionAt")
        })
        return _obj





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.125
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, conlist
from helix_platform_api_public_client.models.attachment import Attachment
from helix_platform_api_public_client.models.business_process_step_attempt import BusinessProcessStepAttempt
from helix_platform_api_public_client.models.business_process_step_logic_type import BusinessProcessStepLogicType
from helix_platform_api_public_client.models.business_process_step_type import BusinessProcessStepType
from helix_platform_api_public_client.models.data_flow_direction import DataFlowDirection
from helix_platform_api_public_client.models.interface import Interface

class BusinessProcessStepBlock(BaseModel):
    """
    BusinessProcessStepBlock
    """
    block_type: StrictStr = Field(..., alias="blockType")
    step_type: BusinessProcessStepType = Field(..., alias="stepType")
    logic_type: BusinessProcessStepLogicType = Field(..., alias="logicType")
    data_flow_direction: Optional[DataFlowDirection] = Field(None, alias="dataFlowDirection")
    interface: Optional[Interface] = None
    id: Optional[StrictStr] = Field(None, description="Unique identifier for the record in UUID4 format")
    resolvable: StrictBool = Field(...)
    rerunnable: StrictBool = Field(...)
    attempts: conlist(BusinessProcessStepAttempt) = Field(...)
    file: Optional[Attachment] = None
    __properties = ["blockType", "stepType", "logicType", "dataFlowDirection", "interface", "id", "resolvable", "rerunnable", "attempts", "file"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> BusinessProcessStepBlock:
        """Create an instance of BusinessProcessStepBlock from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of step_type
        if self.step_type:
            _dict['stepType'] = self.step_type.to_dict()
        # override the default output from pydantic by calling `to_dict()` of interface
        if self.interface:
            _dict['interface'] = self.interface.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in attempts (list)
        _items = []
        if self.attempts:
            for _item in self.attempts:
                if _item:
                    _items.append(_item.to_dict())
            _dict['attempts'] = _items
        # override the default output from pydantic by calling `to_dict()` of file
        if self.file:
            _dict['file'] = self.file.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> BusinessProcessStepBlock:
        """Create an instance of BusinessProcessStepBlock from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return BusinessProcessStepBlock.parse_obj(obj)

        _obj = BusinessProcessStepBlock.parse_obj({
            "block_type": obj.get("blockType"),
            "step_type": BusinessProcessStepType.from_dict(obj.get("stepType")) if obj.get("stepType") is not None else None,
            "logic_type": obj.get("logicType"),
            "data_flow_direction": obj.get("dataFlowDirection"),
            "interface": Interface.from_dict(obj.get("interface")) if obj.get("interface") is not None else None,
            "id": obj.get("id"),
            "resolvable": obj.get("resolvable"),
            "rerunnable": obj.get("rerunnable"),
            "attempts": [BusinessProcessStepAttempt.from_dict(_item) for _item in obj.get("attempts")] if obj.get("attempts") is not None else None,
            "file": Attachment.from_dict(obj.get("file")) if obj.get("file") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.125
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from helix_platform_api_public_client.models.business_process_content_block import BusinessProcessContentBlock  # noqa: E501

class TestBusinessProcessContentBlock(unittest.TestCase):
    """BusinessProcessContentBlock unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BusinessProcessContentBlock:
        """Test BusinessProcessContentBlock
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BusinessProcessContentBlock`
        """
        model = BusinessProcessContentBlock()  # noqa: E501
        if include_optional:
            return BusinessProcessContentBlock(
                block_type = '',
                blocks = [
                    [
                        null
                        ]
                    ],
                step_type = helix_platform_api_public_client.models.business_process_step_type.BusinessProcessStepType(
                    id = '', 
                    display_name = '', ),
                logic_type = 'INTERNAL_LOGIC',
                data_flow_direction = 'INCOMING',
                interface = helix_platform_api_public_client.models.interface.Interface(
                    id = '', 
                    display_name = '', ),
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                resolvable = True,
                rerunnable = True,
                attempts = [
                    helix_platform_api_public_client.models.business_process_step_attempt.BusinessProcessStepAttempt(
                        status = 'SCHEDULED', 
                        started_at = '2022-01-04T00:00Z', 
                        ended_at = '2022-01-04T00:00Z', 
                        fail_reason = '', )
                    ],
                file = helix_platform_api_public_client.models.attachment.Attachment(
                    id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                    file_name = '', 
                    file_size = 0, 
                    mime_type = '', 
                    url = '', )
            )
        else:
            return BusinessProcessContentBlock(
                block_type = '',
                blocks = [
                    [
                        null
                        ]
                    ],
                step_type = helix_platform_api_public_client.models.business_process_step_type.BusinessProcessStepType(
                    id = '', 
                    display_name = '', ),
                logic_type = 'INTERNAL_LOGIC',
                resolvable = True,
                rerunnable = True,
                attempts = [
                    helix_platform_api_public_client.models.business_process_step_attempt.BusinessProcessStepAttempt(
                        status = 'SCHEDULED', 
                        started_at = '2022-01-04T00:00Z', 
                        ended_at = '2022-01-04T00:00Z', 
                        fail_reason = '', )
                    ],
        )
        """

    def testBusinessProcessContentBlock(self):
        """Test BusinessProcessContentBlock"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.125
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from helix_platform_api_public_client.models.audit_log_user import AuditLogUser  # noqa: E501

class TestAuditLogUser(unittest.TestCase):
    """AuditLogUser unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AuditLogUser:
        """Test AuditLogUser
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AuditLogUser`
        """
        model = AuditLogUser()  # noqa: E501
        if include_optional:
            return AuditLogUser(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                name = '',
                role = 'ICO_ADMIN',
                organisation = helix_platform_api_public_client.models.audit_log_user_organisation.AuditLogUserOrganisation(
                    id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                    name = '', )
            )
        else:
            return AuditLogUser(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                name = '',
                role = 'ICO_ADMIN',
                organisation = helix_platform_api_public_client.models.audit_log_user_organisation.AuditLogUserOrganisation(
                    id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                    name = '', ),
        )
        """

    def testAuditLogUser(self):
        """Test AuditLogUser"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
